import React from "react";
import ProductRow from "./ProductRow.jsx";
import { Table, Container } from "react-bootstrap";
import { deleteProduct } from "../actions/apiRequests";
import { withRouter } from "react-router";
import Search from "./Search.jsx";

class SearchResults extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      results: this.props.history.location.state.results
    }
    this.handleDelete = this.handleDelete.bind(this);
  }

  handleDelete(sku) {
    deleteProduct(sku)
      .then(() => {
        const newResults = this.state.results.filter(product => product.sku !== sku);
        this.setState({ results: newResults });
        this.props.history.push("/searchResults", this.state);
      });
  }

  render() {
    return (
      <div className="container flex-column d-flex justify-content-center">
        <div className="container mt-3 d-flex justify-content-between align-items-center">

          <h1 id="title" >Search Results</h1>
        <div><Search /></div>
        </div>
        {this.state.results.length > 0 ?
          <Container id="prod-table" className="mt-3 mx-auto">
          <Table>
            <thead>
              <tr>
                <th>SKU</th>
                <th>UPC</th>
                <th>Product Name</th>
                <th>Price</th>
                <th>Category</th>
                <th>Available Stock</th>
                <th>Blocked Stock</th>
                <th>Fulfilled Stock</th>
              </tr>
            </thead>
            <tbody>
              {this.state.results.map((product) => {
                return (
                  <ProductRow key={product.sku} product={product} handleDelete={() => this.handleDelete(product.sku)} />
                );
              })}
            </tbody>
          </Table>
          </Container>
          :
          <p>Unable to find any matching products.</p>
        }
      </div>
    );
  }

}

export default withRouter(SearchResults);